
 ### BACKUPER
 # Simple script to backup directories using rsync
 # Author: LuX
 # Version: 0.2
 # License: GPL3

# ./backuper.sh <options> dir-list.txt #

ONLYLIST=false
VERBOSE=false
LOGFILE=/tmp/backup.log
EXCLUDES="" #TODO- put this into the list-file just like DETINATION
EXCLUDELIST=""
RSYNC_OPTIONS="-ah" # -z for compress and --progress

if [[ "$1" == "--list-only" ]]; then
	ONLYLIST=true
	LISTFILE="$2"
	[[ -e "$3" ]] && EXCLUDELIST="$3"
elif [[ "$1" == "-v" ]]; then
	VERBOSE=true
	LISTFILE="$2"
	[[ -e "$3" ]] && EXCLUDELIST="$3"
else
	LISTFILE="$1"
	[[ -e "$2" ]] && EXCLUDELIST="$2"
fi
if [[ "$LISTFILE" == "" ]]; then
	echo -e "\n  Usage: $0 <options> list_file_path <exclude_file_path>
		
  Options:
  	--list-only	Only simulate and output a list of incremental files to transfer
  	-v		Verbose, display each transfer occurring


  Info:
  	It requires a list-file to be parsed.
	TOPDIR indicates the source directory to work upon.
	DESTINATION is the directory to copy.
	
	Examples for lists file	[mybackup.list]:

	DESTINATION=/media/backup-home
	TOPDIR=/home/foo

	Documents/work #only the work subdir
	Pictures/Photos/Recent
	.config/someprog/only_a_single_file #will only copy this file
	Projects



	A second list-file can be parsed to exclude files [mybackup.exclude-list]:

	Pictures/Photos/Recent/discarded
	Projects/rejected
	Documents/work/old
	"
	exit
fi
if ! [[ -e "$LISTFILE" ]]; then
	echo "Provide a list-file" && exit
fi

DEST_DIR="$(grep 'DESTINATION=' "$LISTFILE" | cut -d'=' -f2)"
[[ "$DEST_DIR" == "" ]] && DEST_DIR="$(grep 'DESTINATION ' "$LISTFILE" | cut -d' ' -f2)"
SRC_DIR="$(grep 'TOPDIR=' "$LISTFILE" | cut -d'=' -f2)"
[[ "$SRC_DIR" == "" ]] && SRC_DIR="$(grep 'TOPDIR ' "$LISTFILE" | cut -d' ' -f2)"
if [[ "$DEST_DIR" == "" ]]; then
       echo "No DESTINATION found on list-file $LISTFILE"
       exit
elif [[ "$SRC_DIR" == "" ]]; then
       echo "No DESTINATION found on list-file $LISTFILE"
else
	echo "Using backup list: $LISTFILE   ($SRC_DIR) ---> ($DEST_DIR)"
	[[ "$EXCLUDELIST" == "" ]] || echo "Using exclude list: $EXCLUDELIST"
	cat $LISTFILE | grep -v '#' | grep -v 'DESTINATION=' | grep -v 'TOPDIR=' > $LOGFILE
	if $ONLYLIST; then
		echo "Simulating backup (only list)"
		[[ -e $EXCLUDELIST ]] && rsync $RSYNC_OPTIONS --list-only --files-from=$LOGFILE -r --exclude-from=$EXCLUDELIST $SRC_DIR $DEST_DIR || rsync $RSYNC_OPTIONS --list-only --files-from=$LOGFILE -r $SRC_DIR $DEST_DIR 
	       exit
	fi
	BKP_PROCSTART=$(date "+%Y/%m/%d %H:%M:%S")
	#--progress ??
	$VERBOSE && RSYNC_OPTIONS=$RSYNC_OPTIONS"vP" || RSYNC_OPTIONS=$RSYNC_OPTIONS" --info=progress2"
	#$VERBOSE && RSYNC_OPTIONS=$RSYNC_OPTIONS"vP"
	if [[ -e "$EXCLUDELIST" ]]; then
		BKP_INCLIST=$(rsync $RSYNC_OPTIONS --list-only --files-from=$LOGFILE -r --exclude-from=$EXCLUDELIST $SRC_DIR $DEST_DIR)
		rsync $RSYNC_OPTIONS --files-from=$LOGFILE -r --exclude-from=$EXCLUDELIST $SRC_DIR $DEST_DIR
	else
		BKP_INCLIST=$(rsync $RSYNC_OPTIONS --list-only --files-from=$LOGFILE -r $SRC_DIR $DEST_DIR)
		rsync $RSYNC_OPTIONS --files-from=$LOGFILE -r $SRC_DIR $DEST_DIR
	fi
	BKP_PROCEND=$(date "+%Y/%m/%d %H:%M:%S")
	echo "Backup started -- $BKP_PROCSTART" > $LOGFILE
	echo "$BKP_INCLIST" >> $LOGFILE
	echo "Backup finished -- $BKP_PROCEND" >> $LOGFILE

fi
